@@ -16,10 +16,14 @@
 
 #include "tkPort.h"
 #include "tkInt.h"
-#ifdef USE_NCURSES_H
-#   include <ncurses.h>
-#else
-#   include <curses.h>
+#ifdef HAVE_CURSES_H
+#  include <curses.h>
+#elif defined(HAVE_CURSES_CURSES_H)
+#  include <curses/curses.h>
+#elif defined(HAVE_CURSES_NCURSES_H)
+#  include <curses/ncurses.h>
+#elif defined(HAVE_NCURSES_NCURSES_H)
+#  include <ncurses/ncurses.h>
 #endif
 
 /*
