@@ -527,8 +527,10 @@ DoConfig(interp, tkwin, specPtr, value, valueIsUid, widgRec)
 		}
 		break;
 	    default: {
-		sprintf(interp->result, "bad config table: unknown type %d",
+		char buffer[100];
+		sprintf(buffer, "bad config table: unknown type %d",
 			specPtr->type);
+		Tcl_SetResult(interp, buffer, TCL_VOLATILE);
 		return TCL_ERROR;
 	    }
 	}
@@ -605,8 +607,9 @@ Tk_ConfigureInfo(interp, tkwin, specs, widgRec, argvName, flags)
 	if (specPtr == NULL) {
 	    return TCL_ERROR;
 	}
-	interp->result = FormatConfigInfo(interp, tkwin, specPtr, widgRec);
-	interp->freeProc = (Tcl_FreeProc *) free;
+	Tcl_SetResult(interp, 
+			FormatConfigInfo(interp, tkwin, specPtr, widgRec), 
+			(Tcl_FreeProc *) free);
 	return TCL_OK;
     }
 
@@ -860,8 +863,14 @@ Tk_ConfigureValue(interp, tkwin, specs, widgRec, argvName, flags)
 	}
 	return TCL_ERROR;
     }
-    interp->result = FormatConfigValue(interp, tkwin, specPtr, widgRec,
-	    interp->result, &interp->freeProc);
+    {
+      char buffer[200];
+      char *cp;
+      Tcl_FreeProc *fp = 0;
+      cp = FormatConfigValue(interp, tkwin, specPtr, widgRec,
+	    buffer, &fp);
+      Tcl_SetResult(interp, cp, fp);
+    }
     return TCL_OK;
 }
 
