@@ -287,7 +287,7 @@ Tk_ListboxCmd(clientData, interp, argc, argv)
 	goto error;
     }
 
-    interp->result = Tk_PathName(listPtr->tkwin);
+    Tcl_SetResult(interp,Tk_PathName(listPtr->tkwin),TCL_VOLATILE);
     return TCL_OK;
 
     error:
@@ -367,9 +367,11 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 	}
 	if ((index >= listPtr->topIndex) && (index < listPtr->numElements)
 		    && (index < (listPtr->topIndex + listPtr->numLines))) {
+	    char buffer[60];
 	    x = listPtr->borderWidth - listPtr->xOffset;
 	    y = index - listPtr->topIndex + listPtr->borderWidth;
-	    sprintf(interp->result, "%d %d %d %d", x, y, elPtr->textLength, 1);
+	    sprintf(buffer, "%d %d %d %d", x, y, elPtr->textLength, 1);
+	    Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 	}
     } else if ((c == 'c') && (strncmp(argv[1], "cget", length) == 0)
 	    && (length >= 2)) {
@@ -459,7 +461,7 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 	}
 	if (elPtr != NULL) {
 	    if (argc == 3) {
-		interp->result = elPtr->text;
+		Tcl_SetResult(interp,elPtr->text,TCL_VOLATILE);
 	    } else {
 		for (  ; i <= last; i++, elPtr = elPtr->nextPtr) {
 		    Tcl_AppendElement(interp, elPtr->text);
@@ -480,7 +482,11 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 		!= TCL_OK) {
 	    goto error;
 	}
-	sprintf(interp->result, "%d", index);
+	{
+	  char buffer[20];
+	  sprintf(buffer, "%d", index);
+	  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+	}
     } else if ((c == 'i') && (strncmp(argv[1], "insert", length) == 0)
 	    && (length >= 3)) {
 	int index;
@@ -508,7 +514,11 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 	    goto error;
 	}
 	index = NearestListboxElement(listPtr, y);
-	sprintf(interp->result, "%d", index);
+	{
+	  char buffer[20];
+	  sprintf(buffer, "%d", index);
+	  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+	}
     } else if ((c == 's') && (length >= 2)
 	    && (strncmp(argv[1], "scan", length) == 0)) {
 	result = Ctk_Unsupported(interp, "listbox scan");
@@ -587,9 +597,9 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 		/* Empty loop body. */
 	    }
 	    if ((elPtr != NULL) && (elPtr->selected)) {
-		interp->result = "1";
+		Tcl_SetResult(interp,"1",TCL_STATIC);
 	    } else {
-		interp->result = "0";
+		Tcl_SetResult(interp,"0",TCL_STATIC);
 	    }
 	} else if ((c == 's') && (strncmp(argv[2], "set", length) == 0)) {
 	    ListboxSelect(listPtr, first, last, 1);
@@ -606,7 +616,11 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 		    argv[0], " size\"", (char *) NULL);
 	    goto error;
 	}
-	sprintf(interp->result, "%d", listPtr->numElements);
+	{
+	  char buffer[20];
+	  sprintf(buffer, "%d", listPtr->numElements);
+	  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+	}
     } else if ((c == 'x') && (strncmp(argv[1], "xview", length) == 0)) {
 	int index, count, type, windowWidth, windowUnits;
 	int offset = 0;		/* Initialized to stop gcc warnings. */
@@ -615,7 +629,7 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 	windowWidth = Tk_Width(listPtr->tkwin) - 2*listPtr->borderWidth;
 	if (argc == 2) {
 	    if (listPtr->maxWidth == 0) {
-		interp->result = "0 1";
+		Tcl_SetResult(interp,"0 1",TCL_STATIC);
 	    } else {
 		fraction = listPtr->xOffset/((double) listPtr->maxWidth);
 		fraction2 = (listPtr->xOffset + windowWidth)
@@ -623,7 +637,11 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 		if (fraction2 > 1.0) {
 		    fraction2 = 1.0;
 		}
-		sprintf(interp->result, "%g %g", fraction, fraction2);
+		{
+		  char buffer[60];
+		  sprintf(buffer, "%g %g", fraction, fraction2);
+		  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+		}
 	    }
 	} else if (argc == 3) {
 	    if (Tcl_GetInt(interp, argv[2], &index) != TCL_OK) {
@@ -658,7 +676,7 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 
 	if (argc == 2) {
 	    if (listPtr->numElements == 0) {
-		interp->result = "0 1";
+		Tcl_SetResult(interp,"0 1", TCL_STATIC);
 	    } else {
 		fraction = listPtr->topIndex/((double) listPtr->numElements);
 		fraction2 = (listPtr->topIndex+listPtr->numLines)
@@ -666,7 +684,11 @@ ListboxWidgetCmd(clientData, interp, argc, argv)
 		if (fraction2 > 1.0) {
 		    fraction2 = 1.0;
 		}
-		sprintf(interp->result, "%g %g", fraction, fraction2);
+		{
+		  char buffer[60];
+		  sprintf(buffer, "%g %g", fraction, fraction2);
+		  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+		}
 	    }
 	} else if (argc == 3) {
 	    if (GetListboxIndex(interp, listPtr, argv[2], 0, &index)
@@ -1207,7 +1229,7 @@ ListboxEventProc(clientData, eventPtr)
 		    Tcl_GetCommandName(listPtr->interp, listPtr->widgetCmd));
 	}
 	if (listPtr->flags & REDRAW_PENDING) {
-	    Tk_CancelIdleCall(DisplayListbox, (ClientData) listPtr);
+	    Tcl_CancelIdleCall(DisplayListbox, (ClientData) listPtr);
 	}
 	Tk_EventuallyFree((ClientData) listPtr, DestroyListbox);
     } else if (eventPtr->type == CTK_MAP_EVENT) {
@@ -1379,7 +1401,7 @@ ChangeListboxView(listPtr, index)
     if (listPtr->topIndex != index) {
 	listPtr->topIndex = index;
 	if (!(listPtr->flags & REDRAW_PENDING)) {
-	    Tk_DoWhenIdle(DisplayListbox, (ClientData) listPtr);
+	    Tcl_DoWhenIdle(DisplayListbox, (ClientData) listPtr);
 	    listPtr->flags |= REDRAW_PENDING;
 	}
 	listPtr->flags |= UPDATE_V_SCROLLBAR;
@@ -1566,7 +1588,7 @@ ListboxRedrawRange(listPtr, first, last)
 	    || (listPtr->flags & REDRAW_PENDING)) {
 	return;
     }
-    Tk_DoWhenIdle(DisplayListbox, (ClientData) listPtr);
+    Tcl_DoWhenIdle(DisplayListbox, (ClientData) listPtr);
     listPtr->flags |= REDRAW_PENDING;
 }
 
@@ -1618,7 +1640,7 @@ ListboxUpdateVScrollbar(listPtr)
     if (result != TCL_OK) {
 	Tcl_AddErrorInfo(listPtr->interp,
 		"\n    (vertical scrolling command executed by listbox)");
-	Tk_BackgroundError(listPtr->interp);
+	Tcl_BackgroundError(listPtr->interp);
     }
 }
 
@@ -1671,6 +1693,6 @@ ListboxUpdateHScrollbar(listPtr)
     if (result != TCL_OK) {
 	Tcl_AddErrorInfo(listPtr->interp,
 		"\n    (horizontal scrolling command executed by listbox)");
-	Tk_BackgroundError(listPtr->interp);
+	Tcl_BackgroundError(listPtr->interp);
     }
 }
