@@ -355,7 +355,7 @@ Tk_MenuCmd(clientData, interp, argc, argv)
 	goto error;
     }
 
-    interp->result = Tk_PathName(menuPtr->tkwin);
+    Tcl_SetResult(interp,Tk_PathName(menuPtr->tkwin), TCL_VOLATILE);
     return TCL_OK;
 
     error:
@@ -501,7 +501,7 @@ MenuWidgetCmd(clientData, interp, argc, argv)
 	}
 	if (!(menuPtr->flags & RESIZE_PENDING)) {
 	    menuPtr->flags |= RESIZE_PENDING;
-	    Tk_DoWhenIdle(ComputeMenuGeometry, (ClientData) menuPtr);
+	    Tcl_DoWhenIdle(ComputeMenuGeometry, (ClientData) menuPtr);
 	}
     } else if ((c == 'e') && (length >= 7)
 	    && (strncmp(argv[1], "entrycget", length) == 0)) {
@@ -567,9 +567,11 @@ MenuWidgetCmd(clientData, interp, argc, argv)
 	    goto error;
 	}
 	if (index < 0) {
-	    interp->result = "none";
+	    Tcl_SetResult(interp,"none", TCL_STATIC);
 	} else {
-	    sprintf(interp->result, "%d", index);
+	    char buffer[20];
+	    sprintf(buffer, "%d", index);
+	    Tcl_SetResult(interp, buffer, TCL_VOLATILE);
 	}
     } else if ((c == 'i') && (strncmp(argv[1], "insert", length) == 0)
 	    && (length >= 3)) {
@@ -662,7 +664,7 @@ MenuWidgetCmd(clientData, interp, argc, argv)
 		return result;
 	    }
 	    if (menuPtr->flags & RESIZE_PENDING) {
-		Tk_CancelIdleCall(ComputeMenuGeometry, (ClientData) menuPtr);
+		Tcl_CancelIdleCall(ComputeMenuGeometry, (ClientData) menuPtr);
 		ComputeMenuGeometry((ClientData) menuPtr);
 	    }
 	}
@@ -710,22 +712,22 @@ MenuWidgetCmd(clientData, interp, argc, argv)
 	mePtr = menuPtr->entries[index];
 	switch (mePtr->type) {
 	    case COMMAND_ENTRY:
-		interp->result = "command";
+		Tcl_SetResult(interp,"command",TCL_STATIC);
 		break;
 	    case SEPARATOR_ENTRY:
-		interp->result = "separator";
+		Tcl_SetResult(interp,"separator",TCL_STATIC);
 		break;
 	    case CHECK_BUTTON_ENTRY:
-		interp->result = "checkbutton";
+		Tcl_SetResult(interp,"checkbutton",TCL_STATIC);
 		break;
 	    case RADIO_BUTTON_ENTRY:
-		interp->result = "radiobutton";
+		Tcl_SetResult(interp,"radiobutton",TCL_STATIC);
 		break;
 	    case CASCADE_ENTRY:
-		interp->result = "cascade";
+		Tcl_SetResult(interp,"cascade",TCL_STATIC);
 		break;
 	    case TEAROFF_ENTRY:
-		interp->result = "tearoff";
+		Tcl_SetResult(interp,"tearoff",TCL_STATIC);
 		break;
 	}
     } else if ((c == 'u') && (strncmp(argv[1], "unpost", length) == 0)) {
@@ -756,10 +758,12 @@ MenuWidgetCmd(clientData, interp, argc, argv)
 	    goto error;
 	}
 	if (index < 0 || menuPtr->numRows == 0) {
-	    interp->result = "0";
+	    Tcl_SetResult(interp,"0",TCL_STATIC);
 	} else {
-	    sprintf(interp->result, "%d",
+	    char buffer[20];
+	    sprintf(buffer, "%d",
 		    (index%menuPtr->numRows) + menuPtr->borderWidth);
+	    Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 	}
     } else {
 	Tcl_AppendResult(interp, "bad option \"", argv[1],
@@ -942,7 +946,7 @@ ConfigureMenu(interp, menuPtr, argc, argv, flags)
 
     if (!(menuPtr->flags & RESIZE_PENDING)) {
 	menuPtr->flags |= RESIZE_PENDING;
-	Tk_DoWhenIdle(ComputeMenuGeometry, (ClientData) menuPtr);
+	Tcl_DoWhenIdle(ComputeMenuGeometry, (ClientData) menuPtr);
     }
 
     Tk_SetInternalBorder(menuPtr->tkwin, menuPtr->borderWidth);
@@ -994,7 +998,7 @@ ConfigureMenuEntry(interp, menuPtr, mePtr, index, argc, argv, flags)
     if (menuPtr->postedCascade == mePtr) {
 	if (PostSubmenu(menuPtr->interp, menuPtr, (MenuEntry *) NULL)
 		!= TCL_OK) {
-	    Tk_BackgroundError(menuPtr->interp);
+	    Tcl_BackgroundError(menuPtr->interp);
 	}
     }
 
@@ -1089,7 +1093,7 @@ ConfigureMenuEntry(interp, menuPtr, mePtr, index, argc, argv, flags)
 
     if (!(menuPtr->flags & RESIZE_PENDING)) {
 	menuPtr->flags |= RESIZE_PENDING;
-	Tk_DoWhenIdle(ComputeMenuGeometry, (ClientData) menuPtr);
+	Tcl_DoWhenIdle(ComputeMenuGeometry, (ClientData) menuPtr);
     }
     return TCL_OK;
 }
@@ -1465,10 +1469,10 @@ MenuEventProc(clientData, eventPtr)
 		    Tcl_GetCommandName(menuPtr->interp, menuPtr->widgetCmd));
 	}
 	if (menuPtr->flags & REDRAW_PENDING) {
-	    Tk_CancelIdleCall(DisplayMenu, (ClientData) menuPtr);
+	    Tcl_CancelIdleCall(DisplayMenu, (ClientData) menuPtr);
 	}
 	if (menuPtr->flags & RESIZE_PENDING) {
-	    Tk_CancelIdleCall(ComputeMenuGeometry, (ClientData) menuPtr);
+	    Tcl_CancelIdleCall(ComputeMenuGeometry, (ClientData) menuPtr);
 	}
 	Tk_EventuallyFree((ClientData) menuPtr, DestroyMenu);
     } else if (eventPtr->type == CTK_FOCUS_EVENT) {
@@ -1786,7 +1790,7 @@ EventuallyRedrawMenu(menuPtr, mePtr)
 	    || (menuPtr->flags & REDRAW_PENDING)) {
 	return;
     }
-    Tk_DoWhenIdle(DisplayMenu, (ClientData) menuPtr);
+    Tcl_DoWhenIdle(DisplayMenu, (ClientData) menuPtr);
     menuPtr->flags |= REDRAW_PENDING;
 }
 
