@@ -254,7 +254,7 @@ Tk_MenubuttonCmd(clientData, interp, argc, argv)
 	return TCL_ERROR;
     }
 
-    interp->result = Tk_PathName(mbPtr->tkwin);
+    Tcl_SetResult(interp,Tk_PathName(mbPtr->tkwin),TCL_VOLATILE);
     return TCL_OK;
 }
 
@@ -473,7 +473,7 @@ ConfigureMenuButton(interp, mbPtr, argc, argv, flags)
      */
 
     if (Tk_IsMapped(mbPtr->tkwin) && !(mbPtr->flags & REDRAW_PENDING)) {
-	Tk_DoWhenIdle(DisplayMenuButton, (ClientData) mbPtr);
+	Tcl_DoWhenIdle(DisplayMenuButton, (ClientData) mbPtr);
 	mbPtr->flags |= REDRAW_PENDING;
     }
 
@@ -600,7 +600,7 @@ MenuButtonEventProc(clientData, eventPtr)
     MenuButton *mbPtr = (MenuButton *) clientData;
     if (eventPtr->type == CTK_EXPOSE_EVENT) {
 	if ((mbPtr->tkwin != NULL) && !(mbPtr->flags & REDRAW_PENDING)) {
-	    Tk_DoWhenIdle(DisplayMenuButton, (ClientData) mbPtr);
+	    Tcl_DoWhenIdle(DisplayMenuButton, (ClientData) mbPtr);
 	    mbPtr->flags |= REDRAW_PENDING;
 	}
     } else if (eventPtr->type == CTK_DESTROY_EVENT) {
@@ -610,7 +610,7 @@ MenuButtonEventProc(clientData, eventPtr)
 		Tcl_GetCommandName(mbPtr->interp, mbPtr->widgetCmd));
 	}
 	if (mbPtr->flags & REDRAW_PENDING) {
-	    Tk_CancelIdleCall(DisplayMenuButton, (ClientData) mbPtr);
+	    Tcl_CancelIdleCall(DisplayMenuButton, (ClientData) mbPtr);
 	}
 	Tk_EventuallyFree((ClientData) mbPtr, DestroyMenuButton);
     } else if (eventPtr->type == CTK_FOCUS_EVENT) {
@@ -763,7 +763,7 @@ MenuButtonTextVarProc(clientData, interp, name1, name2, flags)
 
     if ((mbPtr->tkwin != NULL) && Tk_IsMapped(mbPtr->tkwin)
 	    && !(mbPtr->flags & REDRAW_PENDING)) {
-	Tk_DoWhenIdle(DisplayMenuButton, (ClientData) mbPtr);
+	Tcl_DoWhenIdle(DisplayMenuButton, (ClientData) mbPtr);
 	mbPtr->flags |= REDRAW_PENDING;
     }
     return (char *) NULL;
