@@ -1,5 +1,5 @@
 /* 
- * tkOption.c (CTk) --
+ * tkOption.c (Ctk) --
  *
  *	This module contains procedures to manage the option
  *	database, which allows various strings to be associated
@@ -8,6 +8,7 @@
  * Copyright (c) 1990-1994 The Regents of the University of California.
  * Copyright (c) 1994-1995 Sun Microsystems, Inc.
  * Copyright (c) 1995 Cleveland Clinic Foundation
+ *	adapted from tk4.2b1 by JuanJo <jjciarla@raiz.uncu.edu.ar>
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -531,14 +532,14 @@ Tk_OptionCmd(clientData, interp, argc, argv)
 	}
 	value = Tk_GetOption(window, argv[3], argv[4]);
 	if (value != NULL) {
-	    interp->result = value;
+	    Tcl_SetResult(interp,value,TCL_VOLATILE);
 	}
 	return TCL_OK;
     } else if ((c == 'r') && (strncmp(argv[1], "readfile", length) == 0)) {
 	int priority;
 
 	if ((argc != 3) && (argc != 4)) {
-	    Tcl_AppendResult(interp, "wrong # args:  should be \"",
+	    Tcl_AppendResult(interp, "wrong # args: should be \"",
 		    argv[0], " readfile fileName ?priority?\"",
 		    (char *) NULL);
 	    return TCL_ERROR;
@@ -798,8 +799,10 @@ AddFromString(interp, tkwin, string, priority)
 	dst = name = src;
 	while (*src != ':') {
 	    if ((*src == '\0') || (*src == '\n')) {
-		sprintf(interp->result, "missing colon on line %d",
+		char buffer[100];
+		sprintf(buffer, "missing colon on line %d",
 			lineNum);
+		Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 		return TCL_ERROR;
 	    }
 	    if ((src[0] == '\\') && (src[1] == '\n')) {
@@ -831,7 +834,9 @@ AddFromString(interp, tkwin, string, priority)
 	    src++;
 	}
 	if (*src == '\0') {
-	    sprintf(interp->result, "missing value on line %d", lineNum);
+	    char buffer[100];
+	    sprintf(buffer, "missing value on line %d", lineNum);
+	    Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 	    return TCL_ERROR;
 	}
 
@@ -843,8 +848,10 @@ AddFromString(interp, tkwin, string, priority)
 	dst = value = src;
 	while (*src != '\n') {
 	    if (*src == '\0') {
-		sprintf(interp->result, "missing newline on line %d",
+	        char buffer[100];
+		sprintf(buffer, "missing newline on line %d",
 			lineNum);
+	        Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 		return TCL_ERROR;
 	    }
 	    if ((src[0] == '\\') && (src[1] == '\n')) {
@@ -900,36 +907,47 @@ ReadOptionFile(interp, tkwin, fileName, priority)
 				 * 0 and TK_MAX_PRIO. */
 {
     char *realName, *buffer;
-    int fileId, result;
-    struct stat statBuf;
+    int result, bufferSize;
+    Tcl_Channel chan;
     Tcl_DString newName;
 
-    realName = Tcl_TildeSubst(interp, fileName, &newName);
+    Tcl_DStringInit(&newName);
+    realName = Tcl_TranslateFileName(interp, fileName, &newName);
     if (realName == NULL) {
 	return TCL_ERROR;
     }
-    fileId = open(realName, O_RDONLY, 0);
+    chan = Tcl_OpenFileChannel(interp, realName, "r", 0);
     Tcl_DStringFree(&newName);
-    if (fileId < 0) {
-	Tcl_AppendResult(interp, "couldn't read file \"", fileName, "\"",
-		(char *) NULL);
+    if (chan == NULL) {
 	return TCL_ERROR;
     }
-    if (fstat(fileId, &statBuf) == -1) {
-	Tcl_AppendResult(interp, "couldn't stat file \"", fileName, "\"",
-		(char *) NULL);
-	close(fileId);
-	return TCL_ERROR;
+
+    /*
+     * Compute size of file by seeking to the end of the file.  This will
+     * overallocate if we are performing CRLF translation.
+     */
+    
+    bufferSize = Tcl_Seek(chan, 0L, SEEK_END);
+    (void) Tcl_Seek(chan, 0L, SEEK_SET);
+
+    if (bufferSize < 0) {
+       Tcl_AppendResult(interp, "error seeking to end of file \"",
+               fileName, "\":", Tcl_PosixError(interp), (char *) NULL);
+       Tcl_Close(NULL, chan);
+        return TCL_ERROR;
     }
-    buffer = (char *) ckalloc((unsigned) statBuf.st_size+1);
-    if (read(fileId, buffer, (unsigned) statBuf.st_size) != statBuf.st_size) {
-	Tcl_AppendResult(interp, "error reading file \"", fileName, "\"",
-		(char *) NULL);
-	close(fileId);
-	return TCL_ERROR;
+
+    buffer = (char *) ckalloc((unsigned) bufferSize+1);
+    bufferSize = Tcl_Read(chan, buffer, bufferSize);
+    if (bufferSize < 0) {
+       Tcl_AppendResult(interp, "error reading file \"", fileName, "\":",
+               Tcl_PosixError(interp), (char *) NULL);
+       Tcl_Close(NULL, chan);
+       return TCL_ERROR;
     }
-    close(fileId);
-    buffer[statBuf.st_size] = 0;
+    Tcl_Close(NULL, chan);
+    buffer[bufferSize] = 0;
+
     result = AddFromString(interp, tkwin, buffer, priority);
     ckfree(buffer);
     return result;
@@ -1326,7 +1344,7 @@ ClearOptionTree(arrayPtr)
  * Side effects:
  *	Options are added to those for winPtr's main window.  If
  *	there exists a RESOURCE_MANAGER proprety for winPtr's
- *	display, that is used.  Otherwise, the .Xdefaults file in
+ *	display, that is used.  Otherwise, the .ctkdefaults file in
  *	the user's home directory is used.
  *
  *--------------------------------------------------------------
@@ -1338,7 +1356,6 @@ GetDefaultOptions(interp, winPtr)
     TkWindow *winPtr;		/* Fetch option defaults for main window
 				 * associated with this. */
 {
-    char *home, *fileName;
     int result;
 
     /*
@@ -1346,15 +1363,7 @@ GetDefaultOptions(interp, winPtr)
      * directory.
      */
 
-    home = getenv("HOME");
-    if (home == NULL) {
-	sprintf(interp->result, "no HOME envariable");
-	return TCL_ERROR;
-    }
-    fileName = (char *) ckalloc((unsigned) (strlen(home) + 20));
-    sprintf(fileName, "%s/.ctkdefaults", home);
-    result = ReadOptionFile(interp, (Tk_Window) winPtr, fileName,
-	    TK_USER_DEFAULT_PRIO);
-    ckfree(fileName);
+    result = ReadOptionFile(interp, (Tk_Window) winPtr, "~/.ctkdefaults",
+            TK_USER_DEFAULT_PRIO);
     return result;
 }
