@@ -673,7 +673,7 @@ ConfigureSlave(interp, slavePtr, argc, argv)
     }
     if (!(masterPtr->flags & PARENT_RECONFIG_PENDING)) {
 	masterPtr->flags |= PARENT_RECONFIG_PENDING;
-	Tk_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
+	Tcl_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
     }
     return result;
 }
@@ -901,7 +901,7 @@ MasterStructureProc(clientData, eventPtr)
 	if ((masterPtr->slavePtr != NULL)
 		&& !(masterPtr->flags & PARENT_RECONFIG_PENDING)) {
 	    masterPtr->flags |= PARENT_RECONFIG_PENDING;
-	    Tk_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
+	    Tcl_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
 	}
     } else if (eventPtr->type == DestroyNotify) {
 	for (slavePtr = masterPtr->slavePtr; slavePtr != NULL;
@@ -913,7 +913,7 @@ MasterStructureProc(clientData, eventPtr)
 	Tcl_DeleteHashEntry(Tcl_FindHashEntry(&masterTable,
 		(char *) masterPtr->tkwin));
 	if (masterPtr->flags & PARENT_RECONFIG_PENDING) {
-	    Tk_CancelIdleCall(RecomputePlacement, (ClientData) masterPtr);
+	    Tcl_CancelIdleCall(RecomputePlacement, (ClientData) masterPtr);
 	}
 	masterPtr->tkwin = NULL;
 	ckfree((char *) masterPtr);
@@ -926,7 +926,7 @@ MasterStructureProc(clientData, eventPtr)
 	if ((masterPtr->slavePtr != NULL)
 		&& !(masterPtr->flags & PARENT_RECONFIG_PENDING)) {
 	    masterPtr->flags |= PARENT_RECONFIG_PENDING;
-	    Tk_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
+	    Tcl_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
 	}
     } else if (eventPtr->type == UnmapNotify) {
 	/*
@@ -1012,7 +1012,7 @@ PlaceRequestProc(clientData, tkwin)
     }
     if (!(masterPtr->flags & PARENT_RECONFIG_PENDING)) {
 	masterPtr->flags |= PARENT_RECONFIG_PENDING;
-	Tk_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
+	Tcl_DoWhenIdle(RecomputePlacement, (ClientData) masterPtr);
     }
 }
 
