@@ -240,7 +240,7 @@ Tk_ScrollbarCmd(clientData, interp, argc, argv)
 	goto error;
     }
 
-    interp->result = Tk_PathName(scrollPtr->tkwin);
+    Tcl_SetResult(interp,Tk_PathName(scrollPtr->tkwin),TCL_VOLATILE);
     return TCL_OK;
 
     error:
@@ -338,7 +338,11 @@ ScrollbarWidgetCmd(clientData, interp, argc, argv)
 	} else {
 	    fraction = ((double) pixels / (double) length);
 	}
-	sprintf(interp->result, "%g", fraction);
+	{
+	  char buffer[30];
+	  sprintf(buffer, "%g", fraction);
+	  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+	}
     } else if ((c == 'f') && (strncmp(argv[1], "fraction", length) == 0)) {
 	int x, y, pos, length;
 	double fraction;
@@ -371,7 +375,11 @@ ScrollbarWidgetCmd(clientData, interp, argc, argv)
 	} else if (fraction > 1.0) {
 	    fraction = 1.0;
 	}
-	sprintf(interp->result, "%g", fraction);
+	{
+	  char buffer[30];
+	  sprintf(buffer, "%g", fraction);
+	  Tcl_SetResult(interp,buffer,TCL_VOLATILE);
+	}
     } else if ((c == 'g') && (strncmp(argv[1], "get", length) == 0)) {
 	if (argc != 2) {
 	    Tcl_AppendResult(interp, "wrong # args: should be \"",
@@ -385,9 +393,11 @@ ScrollbarWidgetCmd(clientData, interp, argc, argv)
 	    Tcl_PrintDouble(interp, scrollPtr->lastFraction, last);
 	    Tcl_AppendResult(interp, first, " ", last, (char *) NULL);
 	} else {
-	    sprintf(interp->result, "%d %d %d %d", scrollPtr->totalUnits,
+	    char buffer[100];
+	    sprintf(buffer, "%d %d %d %d", scrollPtr->totalUnits,
 		    scrollPtr->windowUnits, scrollPtr->firstUnit,
 		    scrollPtr->lastUnit);
+	    Tcl_SetResult(interp, buffer, TCL_VOLATILE);
 	}
     } else if ((c == 'i') && (strncmp(argv[1], "identify", length) == 0)) {
         result = Ctk_Unsupported(interp, "scrollbar identify");
@@ -695,7 +705,7 @@ ScrollbarEventProc(clientData, eventPtr)
 		    scrollPtr->widgetCmd));
 	}
 	if (scrollPtr->flags & REDRAW_PENDING) {
-	    Tk_CancelIdleCall(DisplayScrollbar, (ClientData) scrollPtr);
+	    Tcl_CancelIdleCall(DisplayScrollbar, (ClientData) scrollPtr);
 	}
 	Tk_EventuallyFree((ClientData) scrollPtr, DestroyScrollbar);
     } else if (eventPtr->type == CTK_FOCUS_EVENT) {
@@ -849,7 +859,7 @@ EventuallyRedraw(scrollPtr)
 	return;
     }
     if ((scrollPtr->flags & REDRAW_PENDING) == 0) {
-	Tk_DoWhenIdle(DisplayScrollbar, (ClientData) scrollPtr);
+	Tcl_DoWhenIdle(DisplayScrollbar, (ClientData) scrollPtr);
 	scrollPtr->flags |= REDRAW_PENDING;
     }
 }
